/* Stub file for Anjuta Glade 3 Plugin */
#include <libanjuta/anjuta-vcs-status-tree-view.h>
#include <libanjuta/anjuta-drop-entry.h>
#include <libanjuta/anjuta-file-list.h>
#include <libanjuta/anjuta-pkg-config-chooser.h>
#include <libanjuta/anjuta-column-text-view.h>
#include <libanjuta/anjuta-file-drop-entry.h>
#include <libanjuta/anjuta-entry.h>
#include <libanjuta/anjuta-environment-editor.h>
#include <libanjuta/anjuta-tree-combo.h>

/* Link to at least one function of libanjuta to keep it as a dependency */
static void anjuta_glade_unused (void)
{
	anjuta_file_list_new();
}
